==> eiffelstudio-18.01.10.1424.tar: F_code/C15/fi741.c <==
/*
 * Code for class FIND_SEPARATOR_FACILITY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fi741.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FIND_SEPARATOR_FACILITY}.separator_characters */

EIF_REFERENCE F1376_13558 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (13558,RTMS_EX_H(":/-, .",6,872260142));
}

/* {FIND_SEPARATOR_FACILITY}.find_separator */
EIF_INTEGER_32 F1376_13559 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_8 loc3 = (EIF_CHARACTER_8) 0;
	EIF_BOOLEAN loc4 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_CHARACTER_8 tc1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("find_separator", 1375, Current, 4, 2, 19356);
	RTGC;
	RTHOOK(1);
	Result = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result + ((EIF_INTEGER_32) 1L));
	RTHOOK(2);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		RTHOOK(3);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(13558,F1376_13558,(Current)))+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > ti4_1)) break;
		RTHOOK(4);
		tr1 = RTOSCF(13558,F1376_13558,(Current));
		tc1 = F1027_8717(RTCW(tr1), loc1);
		loc2 = F1025_8652(RTCW(arg1), tc1, ((EIF_INTEGER_32) 1L));
		RTHOOK(5);
		if ((EIF_BOOLEAN)(loc2 != ((EIF_INTEGER_32) 0L))) {
			RTHOOK(6);
			loc4 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(7);
			tr1 = RTOSCF(13558,F1376_13558,(Current));
			tc1 = F1027_8717(RTCW(tr1), loc1);
			loc2 = F1025_8652(RTCW(arg1), tc1, arg2);
			RTHOOK(8);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc2 != ((EIF_INTEGER_32) 0L)) && (EIF_BOOLEAN) (loc2 < Result))) {
				RTHOOK(9);
				Result = (EIF_INTEGER_32) loc2;
			}
		}
		RTHOOK(10);
		loc1++;
	}
	RTHOOK(11);
	if ((EIF_BOOLEAN) !loc4) {
		RTHOOK(12);
		loc1 = (EIF_INTEGER_32) arg2;
		RTHOOK(13);
		tr1 = F1027_8797(RTCW(arg1), loc1, (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 2L)));
		tr2 = RTMS_EX_H("[0]",3,5976157);
		tb1 = F1025_8667(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(14);
			loc1 += ((EIF_INTEGER_32) 3L);
		}
		RTHOOK(15);
		loc3 = F1027_8717(RTCW(arg1), loc1);
		for (;;) {
			RTHOOK(16);
			tb1 = '\01';
			ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
			if (!(EIF_BOOLEAN) (loc1 > ti4_2)) {
				tc1 = F1027_8717(RTCW(arg1), loc1);
				tb1 = (EIF_BOOLEAN)(tc1 != loc3);
			}
			if (tb1) break;
			RTHOOK(17);
			loc1++;
			RTHOOK(18);
			ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
			if ((EIF_BOOLEAN) (loc1 <= ti4_2)) {
				RTHOOK(19);
				tb2 = '\0';
				if ((EIF_BOOLEAN)(loc3 == (EIF_CHARACTER_8) 'm')) {
					tc1 = F1027_8717(RTCW(arg1), loc1);
					tb2 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) 'i');
				}
				if (tb2) {
					RTHOOK(20);
					loc3 = F1027_8717(RTCW(arg1), loc1);
				} else {
					RTHOOK(21);
					tb2 = '\0';
					tb3 = '\0';
					if ((EIF_BOOLEAN)(loc3 == (EIF_CHARACTER_8) 'h')) {
						tc1 = F1027_8717(RTCW(arg1), loc1);
						tb3 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) '1');
					}
					if (tb3) {
						tb3 = '\0';
						tb4 = F1019_8358(RTCW(arg1), (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L)));
						if (tb4) {
							tc1 = F1027_8716(RTCW(arg1), (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L)));
							tb3 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) '2');
						}
						tb2 = tb3;
					}
					if (tb2) {
						RTHOOK(22);
						loc1++;
						RTHOOK(23);
						loc3 = F1027_8717(RTCW(arg1), loc1);
					}
				}
			}
		}
		RTHOOK(24);
		Result = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 - ((EIF_INTEGER_32) 1L)) * ((EIF_INTEGER_32) -1L));
	}
	RTHOOK(25);
	RTLE;
	RTEE;
	return Result;
}

/* {FIND_SEPARATOR_FACILITY}.extracted_substrings */
EIF_REFERENCE F1376_13560 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLR(4,Current);
	RTLR(5,Result);
	RTLIU(6);
	
	RTEAA("extracted_substrings", 1375, Current, 2, 3, 19357);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) (arg3 > ((EIF_INTEGER_32) 0L))) {
		RTHOOK(2);
		loc1 = F1027_8797(RTCW(arg1), arg2, (EIF_INTEGER_32) (arg3 - ((EIF_INTEGER_32) 1L)));
		RTHOOK(3);
		loc2 = F1027_8797(RTCW(arg1), arg3, arg3);
	} else {
		RTHOOK(4);
		loc1 = F1027_8797(RTCW(arg1), arg2, (EIF_INTEGER_32) -arg3);
		RTHOOK(5);
		tr1 = RTLNS(eif_new_type(1026, 0x00).id, 1026, _OBJSIZ_1_1_0_3_0_0_0_0_);
		F1025_8640(RTCW(tr1), ((EIF_INTEGER_32) 0L));
		loc2 = (EIF_REFERENCE) tr1;
	}
	RTHOOK(6);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,939,1026,1026,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNTS(typres0.id, 3, 0);
	}
	((EIF_TYPED_VALUE *)tr1+1)->it_r = loc1;
	RTAR(tr1,loc1);
	((EIF_TYPED_VALUE *)tr1+2)->it_r = loc2;
	RTAR(tr1,loc2);
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit741 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C15/fi741.c <==
/*
 * Code for class FIND_SEPARATOR_FACILITY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "fi741.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {FIND_SEPARATOR_FACILITY}.separator_characters */

EIF_REFERENCE F1379_13558 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (13558,RTMS_EX_H(":/-, .",6,872260142));
}

/* {FIND_SEPARATOR_FACILITY}.find_separator */
EIF_INTEGER_32 F1379_13559 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_8 loc3 = (EIF_CHARACTER_8) 0;
	EIF_BOOLEAN loc4 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_CHARACTER_8 tc1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("find_separator", 1378, Current, 4, 2, 19412);
	RTGC;
	RTHOOK(1);
	Result = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result + ((EIF_INTEGER_32) 1L));
	RTHOOK(2);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		RTHOOK(4);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(13558,F1379_13558, (Current)))+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (loc1 > ti4_1)) break;
		RTHOOK(5);
		tr1 = RTOSCF(13558,F1379_13558, (Current));
		tc1 = F1033_8806(RTCW(tr1), loc1);
		loc2 = F1031_8741(RTCW(arg1), tc1, ((EIF_INTEGER_32) 1L));
		RTHOOK(6);
		if ((EIF_BOOLEAN)(loc2 != ((EIF_INTEGER_32) 0L))) {
			RTHOOK(7);
			loc4 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			RTHOOK(8);
			tr1 = RTOSCF(13558,F1379_13558, (Current));
			tc1 = F1033_8806(RTCW(tr1), loc1);
			loc2 = F1031_8741(RTCW(arg1), tc1, arg2);
			RTHOOK(9);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc2 != ((EIF_INTEGER_32) 0L)) && (EIF_BOOLEAN) (loc2 < Result))) {
				RTHOOK(10);
				Result = (EIF_INTEGER_32) loc2;
			}
		}
		RTHOOK(11);
		loc1++;
	}
	RTHOOK(12);
	if ((EIF_BOOLEAN) !loc4) {
		RTHOOK(13);
		loc1 = (EIF_INTEGER_32) arg2;
		RTHOOK(14);
		tr1 = F1033_8886(RTCW(arg1), loc1, (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 2L)));
		tr2 = RTMS_EX_H("[0]",3,5976157);
		tb1 = F1031_8756(RTCW(tr1), tr2);
		if (tb1) {
			RTHOOK(15);
			loc1 += ((EIF_INTEGER_32) 3L);
		}
		RTHOOK(16);
		loc3 = F1033_8806(RTCW(arg1), loc1);
		for (;;) {
			RTHOOK(17);
			tb1 = '\01';
			ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
			if (!(EIF_BOOLEAN) (loc1 > ti4_2)) {
				tc1 = F1033_8806(RTCW(arg1), loc1);
				tb1 = (EIF_BOOLEAN)(tc1 != loc3);
			}
			if (tb1) break;
			RTHOOK(18);
			loc1++;
			RTHOOK(19);
			ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
			if ((EIF_BOOLEAN) (loc1 <= ti4_2)) {
				RTHOOK(20);
				tb2 = '\0';
				if ((EIF_BOOLEAN)(loc3 == (EIF_CHARACTER_8) 'm')) {
					tc1 = F1033_8806(RTCW(arg1), loc1);
					tb2 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) 'i');
				}
				if (tb2) {
					RTHOOK(21);
					loc3 = F1033_8806(RTCW(arg1), loc1);
				} else {
					RTHOOK(22);
					tb2 = '\0';
					tb3 = '\0';
					if ((EIF_BOOLEAN)(loc3 == (EIF_CHARACTER_8) 'h')) {
						tc1 = F1033_8806(RTCW(arg1), loc1);
						tb3 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) '1');
					}
					if (tb3) {
						tb3 = '\0';
						tb4 = F1025_8447(RTCW(arg1), (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L)));
						if (tb4) {
							tc1 = F1033_8805(RTCW(arg1), (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L)));
							tb3 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) '2');
						}
						tb2 = tb3;
					}
					if (tb2) {
						RTHOOK(23);
						loc1++;
						RTHOOK(24);
						loc3 = F1033_8806(RTCW(arg1), loc1);
					}
				}
			}
		}
		RTHOOK(25);
		Result = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 - ((EIF_INTEGER_32) 1L)) * ((EIF_INTEGER_32) -1L));
	}
	RTHOOK(27);
	RTLE;
	RTEE;
	return Result;
}

/* {FIND_SEPARATOR_FACILITY}.extracted_substrings */
EIF_REFERENCE F1379_13560 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,loc2);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,Result);
	RTLIU(6);
	
	RTEAA("extracted_substrings", 1378, Current, 2, 3, 19413);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) (arg3 > ((EIF_INTEGER_32) 0L))) {
		RTHOOK(2);
		loc1 = F1033_8886(RTCW(arg1), arg2, (EIF_INTEGER_32) (arg3 - ((EIF_INTEGER_32) 1L)));
		RTHOOK(3);
		loc2 = F1033_8886(RTCW(arg1), arg3, arg3);
	} else {
		RTHOOK(4);
		loc1 = F1033_8886(RTCW(arg1), arg2, (EIF_INTEGER_32) -arg3);
		RTHOOK(5);
		loc2 = RTLNS(eif_new_type(1032, 0x00).id, 1032, _OBJSIZ_1_1_0_3_0_0_0_0_);
		F1031_8729(RTCW(loc2), ((EIF_INTEGER_32) 0L));
	}
	RTHOOK(6);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,945,1032,1032,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNTS(typres0.id, 3, 0);
	}
	((EIF_TYPED_VALUE *)tr1+1)->it_r = loc1;
	RTAR(tr1,loc1);
	((EIF_TYPED_VALUE *)tr1+2)->it_r = loc2;
	RTAR(tr1,loc2);
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(9);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit741 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
